@@ -41,7 +41,7 @@ TEST_CASE("check have uncompressed")
   REQUIRE(err.code == heif_error_Ok);
 
   const char *name = heif_encoder_get_name(enc);
-  REQUIRE(strcmp(name, "uncompressed") == 0);
+  REQUIRE(strcmp(name, "builtin") == 0);
 
   heif_encoder_release(enc);
 
@@ -632,6 +632,7 @@ static void do_encode(heif_image* input_image, const char* filename, bool check_
   heif_context_free(ctx);
 }
 
+
 TEST_CASE("Encode RGB")
 {
   heif_image *input_image = createImage_RGB_interleaved();
